@@ -26,29 +26,29 @@ from .literals import (
 )
 from .paginator import ListServersPaginator
 from .type_defs import (
-    CreateAccessResponseTypeDef,
-    CreateServerResponseTypeDef,
-    CreateUserResponseTypeDef,
-    DescribeAccessResponseTypeDef,
-    DescribeSecurityPolicyResponseTypeDef,
-    DescribeServerResponseTypeDef,
-    DescribeUserResponseTypeDef,
+    CreateAccessResponseResponseTypeDef,
+    CreateServerResponseResponseTypeDef,
+    CreateUserResponseResponseTypeDef,
+    DescribeAccessResponseResponseTypeDef,
+    DescribeSecurityPolicyResponseResponseTypeDef,
+    DescribeServerResponseResponseTypeDef,
+    DescribeUserResponseResponseTypeDef,
     EndpointDetailsTypeDef,
     HomeDirectoryMapEntryTypeDef,
     IdentityProviderDetailsTypeDef,
-    ImportSshPublicKeyResponseTypeDef,
-    ListAccessesResponseTypeDef,
-    ListSecurityPoliciesResponseTypeDef,
-    ListServersResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
-    ListUsersResponseTypeDef,
+    ImportSshPublicKeyResponseResponseTypeDef,
+    ListAccessesResponseResponseTypeDef,
+    ListSecurityPoliciesResponseResponseTypeDef,
+    ListServersResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
+    ListUsersResponseResponseTypeDef,
     PosixProfileTypeDef,
     ProtocolDetailsTypeDef,
     TagTypeDef,
-    TestIdentityProviderResponseTypeDef,
-    UpdateAccessResponseTypeDef,
-    UpdateServerResponseTypeDef,
-    UpdateUserResponseTypeDef,
+    TestIdentityProviderResponseResponseTypeDef,
+    UpdateAccessResponseResponseTypeDef,
+    UpdateServerResponseResponseTypeDef,
+    UpdateUserResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -83,7 +83,7 @@ class Exceptions:
 
 class TransferClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html)
     """
 
@@ -92,7 +92,9 @@ class TransferClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#can_paginate)
         """
 
@@ -107,9 +109,13 @@ class TransferClient:
         HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None
-    ) -> CreateAccessResponseTypeDef:
+    ) -> CreateAccessResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.create_access)
+        Used by administrators to choose which groups in the directory should have
+        access to upload and download files over the enabled protocols using Amazon Web
+        Services Transfer Family.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_access)
         """
 
@@ -127,9 +133,12 @@ class TransferClient:
         Protocols: List[ProtocolType] = None,
         SecurityPolicyName: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateServerResponseTypeDef:
+    ) -> CreateServerResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.create_server)
+        Instantiates an auto-scaling virtual server based on the selected file transfer
+        protocol in Amazon Web Services.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_server)
         """
 
@@ -146,59 +155,86 @@ class TransferClient:
         PosixProfile: "PosixProfileTypeDef" = None,
         SshPublicKeyBody: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateUserResponseTypeDef:
+    ) -> CreateUserResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.create_user)
+        Creates a user and associates them with an existing file transfer protocol-
+        enabled server.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_user)
         """
 
     def delete_access(self, *, ServerId: str, ExternalId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.delete_access)
+        Allows you to delete the access specified in the `ServerID` and `ExternalID`
+        parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_access)
         """
 
     def delete_server(self, *, ServerId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.delete_server)
+        Deletes the file transfer protocol-enabled server that you specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_server)
         """
 
     def delete_ssh_public_key(self, *, ServerId: str, SshPublicKeyId: str, UserName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        Deletes a user's Secure Shell (SSH) public key.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_ssh_public_key)
         """
 
     def delete_user(self, *, ServerId: str, UserName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.delete_user)
+        Deletes the user belonging to a file transfer protocol-enabled server you
+        specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_user)
         """
 
-    def describe_access(self, *, ServerId: str, ExternalId: str) -> DescribeAccessResponseTypeDef:
+    def describe_access(
+        self, *, ServerId: str, ExternalId: str
+    ) -> DescribeAccessResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.describe_access)
+        Describes the access that is assigned to the specific file transfer protocol-
+        enabled server, as identified by its `ServerId` property and its `ExternalID` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_access)
         """
 
     def describe_security_policy(
         self, *, SecurityPolicyName: str
-    ) -> DescribeSecurityPolicyResponseTypeDef:
+    ) -> DescribeSecurityPolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        Describes the security policy that is attached to your file transfer protocol-
+        enabled server.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_security_policy)
         """
 
-    def describe_server(self, *, ServerId: str) -> DescribeServerResponseTypeDef:
+    def describe_server(self, *, ServerId: str) -> DescribeServerResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.describe_server)
+        Describes a file transfer protocol-enabled server that you specify by passing
+        the `ServerId` parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_server)
         """
 
-    def describe_user(self, *, ServerId: str, UserName: str) -> DescribeUserResponseTypeDef:
+    def describe_user(self, *, ServerId: str, UserName: str) -> DescribeUserResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.describe_user)
+        Describes the user assigned to the specific file transfer protocol-enabled
+        server, as identified by its `ServerId` property.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_user)
         """
 
@@ -210,73 +246,102 @@ class TransferClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#generate_presigned_url)
         """
 
     def import_ssh_public_key(
         self, *, ServerId: str, SshPublicKeyBody: str, UserName: str
-    ) -> ImportSshPublicKeyResponseTypeDef:
+    ) -> ImportSshPublicKeyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        Adds a Secure Shell (SSH) public key to a user account identified by a
+        `UserName` value assigned to the specific file transfer protocol-enabled server,
+        identified by `ServerId` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#import_ssh_public_key)
         """
 
     def list_accesses(
         self, *, ServerId: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListAccessesResponseTypeDef:
+    ) -> ListAccessesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.list_accesses)
+        Lists the details for all the accesses you have on your server.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_accesses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_accesses)
         """
 
     def list_security_policies(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListSecurityPoliciesResponseTypeDef:
+    ) -> ListSecurityPoliciesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        Lists the security policies that are attached to your file transfer protocol-
+        enabled servers.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_security_policies)
         """
 
     def list_servers(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListServersResponseTypeDef:
+    ) -> ListServersResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.list_servers)
+        Lists the file transfer protocol-enabled servers that are associated with your
+        Amazon Web Services account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_servers)
         """
 
     def list_tags_for_resource(
         self, *, Arn: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListTagsForResourceResponseTypeDef:
+    ) -> ListTagsForResourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        Lists all of the tags associated with the Amazon Resource Name (ARN) that you
+        specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_tags_for_resource)
         """
 
     def list_users(
         self, *, ServerId: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListUsersResponseTypeDef:
+    ) -> ListUsersResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.list_users)
+        Lists the users for a file transfer protocol-enabled server that you specify by
+        passing the `ServerId` parameter.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_users)
         """
 
     def start_server(self, *, ServerId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.start_server)
+        Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
+        `ONLINE`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#start_server)
         """
 
     def stop_server(self, *, ServerId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.stop_server)
+        Changes the state of a file transfer protocol-enabled server from `ONLINE` to
+        `OFFLINE`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#stop_server)
         """
 
     def tag_resource(self, *, Arn: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.tag_resource)
+        Attaches a key-value pair to a resource, as identified by its Amazon Resource
+        Name (ARN).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#tag_resource)
         """
 
@@ -288,15 +353,22 @@ class TransferClient:
         ServerProtocol: ProtocolType = None,
         SourceIp: str = None,
         UserPassword: str = None
-    ) -> TestIdentityProviderResponseTypeDef:
+    ) -> TestIdentityProviderResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        If the `IdentityProviderType` of a file transfer protocol-enabled server is
+        `AWS_DIRECTORY_SERVICE` or `API_Gateway` , tests whether your identity provider
+        is set up successfully.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#test_identity_provider)
         """
 
     def untag_resource(self, *, Arn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.untag_resource)
+        Detaches a key-value pair from a resource, as identified by its Amazon Resource
+        Name (ARN).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#untag_resource)
         """
 
@@ -311,9 +383,12 @@ class TransferClient:
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         Role: str = None
-    ) -> UpdateAccessResponseTypeDef:
+    ) -> UpdateAccessResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.update_access)
+        Allows you to update parameters for the access specified in the `ServerID` and
+        `ExternalID` parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.update_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_access)
         """
 
@@ -330,9 +405,12 @@ class TransferClient:
         LoggingRole: str = None,
         Protocols: List[ProtocolType] = None,
         SecurityPolicyName: str = None
-    ) -> UpdateServerResponseTypeDef:
+    ) -> UpdateServerResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.update_server)
+        Updates the file transfer protocol-enabled server's properties after that server
+        has been created.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_server)
         """
 
@@ -347,13 +425,16 @@ class TransferClient:
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         Role: str = None
-    ) -> UpdateUserResponseTypeDef:
+    ) -> UpdateUserResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Client.update_user)
+        Assigns new properties to a user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_user)
         """
 
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Paginator.ListServers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Paginator.ListServers)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
         """
