@@ -22,20 +22,21 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .type_defs import ListServersResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListServersResponseResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListServersPaginator",)
 
 
 class ListServersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Paginator.ListServers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Paginator.ListServers)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListServersResponseTypeDef]:
+    ) -> Iterator[ListServersResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
         """
